@@ -1,24 +1,28 @@
 # updated to NASIS 6.2
 
 # convenience function for loading most commonly used information from local NASIS database
-fetchNASIS <- function(rmHzErrors=TRUE, nullFragsAreZero=TRUE) {
+fetchNASIS <- function(rmHzErrors=TRUE, nullFragsAreZero=TRUE, soilColorState='moist') {
 	
 	# test connection
 	if(! 'nasis_local' %in% names(RODBC::odbcDataSources()))
 			stop('Local NASIS ODBC connection has not been setup. Please see `https://r-forge.r-project.org/scm/viewvc.php/*checkout*/docs/soilDB/setup_local_nasis.html?root=aqp`.')
 	
+  # sanity check
+  if(! soilColorState %in% c('dry', 'moist'))
+    stop('soilColorState must be either `dry` or `moist`', call. = FALSE)
+  
 	# 1. load data in pieces
 	suppressMessages(site_data <- get_site_data_from_NASIS_db())
 	hz_data <- get_hz_data_from_NASIS_db()
 	color_data <- get_colors_from_NASIS_db()
-	extended_data <- get_extended_data_from_NASIS_db()
+	extended_data <- get_extended_data_from_NASIS_db(nullFragsAreZero)
 	
 	# test to see if the selected set is loaded
 	if (nrow(hz_data) == 0 | all(unlist(lapply(extended_data, nrow)) == 0)) message('your selected set is missing either the pedon or site table, please load and try again')
   
+	## this is the "total fragment volume" per NASIS calculation
   # optionally convert NA fragvol to 0
   if(nullFragsAreZero) {
-    hz_data$total_frags_pct <- ifelse(is.na(hz_data$total_frags_pct), 0, hz_data$total_frags_pct)
     hz_data$total_frags_pct_cal <- ifelse(is.na(hz_data$total_frags_pct_cal), 0, hz_data$total_frags_pct_cal)
   }
   
@@ -35,21 +39,18 @@ fetchNASIS <- function(rmHzErrors=TRUE, nullFragsAreZero=TRUE) {
   }
 	
 	
-	# convert colors... in the presence of missing color data
-	h$soil_color <- NA
-	idx <- complete.cases(h$m_r)
-	h$soil_color[idx] <- with(h[idx, ], rgb(m_r, m_g, m_b)) # moist colors
+	## copy pre-computed colors into a convenience field for plotting
+	# moist colors
+	if(soilColorState == 'moist')
+	  h$soil_color <- h$moist_soil_color
 	
-	# join hz + fragment summary
-  hfs <- extended_data$frag_summary
-  # optionally convert NA fragvol to 0
-  if(nullFragsAreZero) {
-    hfs <- as.data.frame(
-      cbind(hfs[, 1, drop=FALSE], 
-            lapply(hfs[, -1], function(i) ifelse(is.na(i), 0, i))
-      ), stringsAsFactors=FALSE)
-  }
-	h <- join(h, hfs, by='phiid', type='left')
+	# dry colors
+	if(soilColorState == 'dry')
+	  h$soil_color <- h$dry_soil_color
+	
+	
+	## join hz + fragment summary
+	h <- join(h, extended_data$frag_summary, by='phiid', type='left')
 	
 	# optionally test for bad horizonation... flag, and remove
   if(rmHzErrors) {
@@ -58,14 +59,18 @@ fetchNASIS <- function(rmHzErrors=TRUE, nullFragsAreZero=TRUE) {
     # which are the good (valid) ones?
     good.ids <- as.character(h.test$peiid[which(h.test$hz_logic_pass)])
     bad.ids <- as.character(h.test$peiid[which(!h.test$hz_logic_pass)])
+    bad.horizons<- h[which(!h.test$hz_logic_pass), c(1:4,6,7)]
     bad.pedon.ids <- site_data$pedon_id[which(site_data$peiid %in% bad.ids)]
     
     # keep the good ones
     h <- h[which(h$peiid %in% good.ids), ]
     
     # keep track of those pedons with horizonation errors
-    if(length(bad.pedon.ids) > 0)
+    if(length(bad.pedon.ids) > 0) {
       assign('bad.pedon.ids', value=bad.pedon.ids, envir=soilDB.env)
+      assign("bad.horizons", value = data.frame(bad.horizons), envir = soilDB.env)
+    }
+      
   }
 	
 	
@@ -87,10 +92,17 @@ fetchNASIS <- function(rmHzErrors=TRUE, nullFragsAreZero=TRUE) {
 	# method is added to the new field called 'selection_method'
 	best.tax.data <- ddply(extended_data$taxhistory, 'peiid', .pickBestTaxHistory)
 	site(h) <- best.tax.data
+
+	# load best-guess optimal records from ecositehistory
+	# method is added to the new field called 'es_selection_method'
+	best.ecosite.data <- ddply(extended_data$ecositehistory, 'siteiid', .pickBestEcosite)
+	site(h) <- best.ecosite.data
 	
 	# add diagnostic boolean data into @site
 	site(h) <- extended_data$diagHzBoolean
 	
+	
+	## TODO: convert this to simplifyFragmentData
 	# add surface frag summary
   sfs <- extended_data$surf_frag_summary
   # optionally convert NA fragvol to 0
@@ -127,7 +139,7 @@ fetchNASIS <- function(rmHzErrors=TRUE, nullFragsAreZero=TRUE) {
 	  message("-> QC: duplicate pedons: use `get('dup.pedon.ids', envir=soilDB.env)` for related peiid values")
   
   if(exists('bad.pedon.ids', envir=soilDB.env))
-	  message("-> QC: horizon errors detected, use `get('bad.pedon.ids', envir=soilDB.env)` for related userpedonid values")
+	  message("-> QC: horizon errors detected, use `get('bad.pedon.ids', envir=soilDB.env)` for related userpedonid values or `get('bad.horizons', envir=soilDB.env)` for related horizon designations")
   
 	# done
 	return(h)
