@@ -2,6 +2,7 @@
 ## December, 2015
 ## D.E. Beaudette
 ## J.M. Scovlin
+## S.M. Roecker
 ## 
 
 ##
@@ -15,28 +16,13 @@ get_component_data_from_NASIS_db <- function() {
   if(!requireNamespace('RODBC'))
     stop('please install the `RODBC` package', call.=FALSE)
   
-  q <- "SELECT dmuiid, dmudesc, coiid, compname, comppct_r, ck.ChoiceName as compkind, majcompflag, localphase, slope_r, tfact, wei, weg, dc.ChoiceName as drainage_class, elev_r, aspectrep, map_r, airtempa_r as maat_r, soiltempa_r as mast_r, reannualprecip_r, ffd_r, nirrcapcl, nirrcapscl, irrcapcl, irrcapscl, fa.ChoiceName as frost_action, hg.ChoiceLabel as hydgrp, crc.ChoiceName as corcon, crs.ChoiceName as corsteel, taxclname, txo.ChoiceName as taxorder, txs.ChoiceName as taxsuborder, txgg.ChoiceName as  taxgrtgroup, txsg.ChoiceName as taxsubgrp, txps.ChoiceName as taxpartsize, txpsm.ChoiceName as taxpartsizemod, txact.ChoiceName as taxceactcl, txr.ChoiceName as taxreaction, txtc.ChoiceName as taxtempcl, txmc.ChoiceName as taxmoistscl, txtr.ChoiceName as taxtempregime, txed.ChoiceName as soiltaxedition
-  FROM
-  component_View_1
-  INNER JOIN datamapunit_View_1 ON datamapunit_View_1.dmuiid = component_View_1.dmuiidref
-  LEFT OUTER JOIN (SELECT * FROM MetadataDomainDetail WHERE DomainID = 148) AS dc ON drainagecl = dc.ChoiceValue
-  LEFT OUTER JOIN (SELECT * FROM MetadataDomainDetail WHERE DomainID = 120) AS fa ON frostact = fa.ChoiceValue
-  LEFT OUTER JOIN (SELECT * FROM MetadataDomainDetail WHERE DomainID = 103) AS crc ON corcon = crc.ChoiceValue
-  LEFT OUTER JOIN (SELECT * FROM MetadataDomainDetail WHERE DomainID = 104) AS crs ON corsteel = crs.ChoiceValue
-  LEFT OUTER JOIN (SELECT * FROM MetadataDomainDetail WHERE DomainID = 102) AS ck ON compkind = ck.ChoiceValue
-  LEFT OUTER JOIN (SELECT * FROM MetadataDomainDetail WHERE DomainID = 132) AS txo ON taxorder = txo.ChoiceValue
-  LEFT OUTER JOIN (SELECT * FROM MetadataDomainDetail WHERE DomainID = 134) AS txs ON taxsuborder = txs.ChoiceValue
-  LEFT OUTER JOIN (SELECT * FROM MetadataDomainDetail WHERE DomainID = 130) AS txgg ON taxgrtgroup = txgg.ChoiceValue
-  LEFT OUTER JOIN (SELECT * FROM MetadataDomainDetail WHERE DomainID = 187) AS txsg ON taxsubgrp = txsg.ChoiceValue
-  LEFT OUTER JOIN (SELECT * FROM MetadataDomainDetail WHERE DomainID = 127) AS txps ON taxpartsize = txps.ChoiceValue
-  LEFT OUTER JOIN (SELECT * FROM MetadataDomainDetail WHERE DomainID = 521) AS txpsm ON taxpartsizemod = txpsm.ChoiceValue
-  LEFT OUTER JOIN (SELECT * FROM MetadataDomainDetail WHERE DomainID = 520) AS txact ON taxceactcl = txact.ChoiceValue
-  LEFT OUTER JOIN (SELECT * FROM MetadataDomainDetail WHERE DomainID = 128) AS txr ON taxreaction = txr.ChoiceValue
-  LEFT OUTER JOIN (SELECT * FROM MetadataDomainDetail WHERE DomainID = 185) AS txtc ON taxtempcl = txtc.ChoiceValue
-  LEFT OUTER JOIN (SELECT * FROM MetadataDomainDetail WHERE DomainID = 131) AS txmc ON taxmoistscl = txmc.ChoiceValue
-  LEFT OUTER JOIN (SELECT * FROM MetadataDomainDetail WHERE DomainID = 188) AS txtr ON taxtempregime = txtr.ChoiceValue
-  LEFT OUTER JOIN (SELECT * FROM MetadataDomainDetail WHERE DomainID = 2030) AS txed ON soiltaxedition = txed.ChoiceValue
-  LEFT OUTER JOIN (SELECT * FROM MetadataDomainDetail WHERE DomainID = 115) AS hg ON hydgrp = hg.ChoiceValue
+  q <- "SELECT dmuiid, dmudesc, coiid, compname, comppct_r, compkind, majcompflag, localphase, slope_r, tfact, wei, weg, drainagecl, elev_r, aspectrep, map_r, airtempa_r as maat_r, soiltempa_r as mast_r, reannualprecip_r, ffd_r, nirrcapcl, nirrcapscl, irrcapcl, irrcapscl, frostact, hydgrp, corcon, corsteel, taxclname, taxorder, taxsuborder, taxgrtgroup, taxsubgrp, taxpartsize, taxpartsizemod, taxceactcl, taxreaction, taxtempcl, taxmoistscl, taxtempregime, soiltaxedition
+  
+  FROM  component
+
+  INNER JOIN datamapunit_View_1 ON datamapunit_View_1.dmuiid = component.dmuiidref
+
+
   ORDER BY dmudesc, coiid, comppct_r DESC;"
   
   # setup connection local NASIS
@@ -60,6 +46,9 @@ get_component_data_from_NASIS_db <- function() {
   if(nrow(d) == 0)
     stop('there are no NASIS components in your selected set!')
   
+  # recode metadata domains
+  d <- .metadata_replace(d)
+  
   # done
   return(d)
 }
@@ -72,18 +61,16 @@ get_component_correlation_data_from_NASIS_db <- function(dropAdditional=TRUE, dr
   if(!requireNamespace('RODBC'))
     stop('please install the `RODBC` package', call.=FALSE)
   
-  q <- "SELECT muiid, musym, nationalmusym, mapunit_View_1.muname, mk.ChoiceName as mukind, ms.ChoiceName as mustatus, muacres, fc.ChoiceLabel as farmlndcl, repdmu, dmuiid, areasymbol, areaname, ss.ChoiceLabel as survey_status, cordate
-  FROM
-  mapunit_View_1
-  LEFT OUTER JOIN lmapunit_View_1 ON lmapunit_View_1.muiidref = mapunit_View_1.muiid
-  LEFT OUTER JOIN legend_View_1 ON legend_View_1.liid = lmapunit_View_1.liidref
-  LEFT OUTER JOIN area_View_1 ON area_View_1.areaiid = legend_View_1.areaiidref
-  LEFT OUTER JOIN correlation_View_1 ON mapunit_View_1.muiid = correlation_View_1.muiidref
-  LEFT OUTER JOIN datamapunit_View_1 ON correlation_View_1.dmuiidref = datamapunit_View_1.dmuiid
-  LEFT OUTER JOIN (SELECT * FROM MetadataDomainDetail WHERE DomainID = 118) AS mk ON mukind = mk.ChoiceValue
-  LEFT OUTER JOIN (SELECT * FROM MetadataDomainDetail WHERE DomainID = 138) AS ms ON mustatus = ms.ChoiceValue
-  LEFT OUTER JOIN (SELECT * FROM MetadataDomainDetail WHERE DomainID = 151) AS fc ON farmlndcl = fc.ChoiceValue
-  LEFT OUTER JOIN (SELECT * FROM MetadataDomainDetail WHERE DomainID = 125) AS ss ON ssastatus = ss.ChoiceValue
+  q <- "SELECT mu.muiid, musym, nationalmusym, mu.muname, mukind, mustatus, muacres, farmlndcl, repdmu, dmuiid, areasymbol, areaname, ssastatus, cordate
+  
+  FROM  mapunit_View_1 mu
+  
+  LEFT OUTER JOIN lmapunit ON lmapunit.muiidref = mu.muiid
+  LEFT OUTER JOIN legend ON legend.liid = lmapunit.liidref
+  LEFT OUTER JOIN area ON area.areaiid = legend.areaiidref
+  LEFT OUTER JOIN correlation ON correlation.muiidref = mu.muiid 
+  LEFT OUTER JOIN datamapunit ON correlation.dmuiidref = datamapunit.dmuiid
+  
   ORDER BY dmuiid;"
   
   # setup connection local NASIS
@@ -99,6 +86,9 @@ get_component_correlation_data_from_NASIS_db <- function(dropAdditional=TRUE, dr
   if(nrow(d) == 0)
     stop('there are no records in your selected set!')
   
+  # recode metadata domains
+  d <- .metadata_replace(d)
+  
   # optionally drop additional | NA mustatus
   if(dropAdditional) {
     idx <- which(! d$mustatus == 'additional')
@@ -142,15 +132,13 @@ get_component_esd_data_from_NASIS_db <- function() {
     stop('please install the `RODBC` package', call.=FALSE)
   
   q <- "SELECT coiidref as coiid, ecositeid, ecositenm, 
-  eo.ChoiceName AS ecositeorigin, et.ChoiceName AS ecositetype, em.ChoiceName AS ecositemlra, el.ChoiceName AS ecositelru, ecositenumber, es.ChoiceName AS ecositestate
-  FROM coecosite_View_1
-  INNER JOIN ecologicalsite_View_1 ON ecositeiidref = ecositeiid
-  LEFT OUTER JOIN (SELECT * FROM MetadataDomainDetail WHERE DomainID = 4913) AS eo ON ecositeorigin = eo.ChoiceValue
-  LEFT OUTER JOIN (SELECT * FROM MetadataDomainDetail WHERE DomainID = 1253) AS et ON ecositetype = et.ChoiceValue
-  LEFT OUTER JOIN (SELECT * FROM MetadataDomainDetail WHERE DomainID = 1252) AS em ON ecositemlra = em.ChoiceValue
-  LEFT OUTER JOIN (SELECT * FROM MetadataDomainDetail WHERE DomainID = 1310) AS el ON ecositelru = el.ChoiceValue
-  LEFT OUTER JOIN (SELECT * FROM MetadataDomainDetail WHERE DomainID = 1298) AS es ON ecositestate = es.ChoiceValue
-  ORDER BY coiid ;"
+  ecositeorigin, ecositetype, ecositemlra, ecositelru, ecositenumber, ecositestate
+  
+  FROM coecosite_View_1 coecosite
+  
+  INNER JOIN ecologicalsite ON ecologicalsite.ecositeiid = coecosite.ecositeiidref
+  
+  ORDER BY coiid;"
   # setup connection local NASIS
   channel <- RODBC::odbcDriverConnect(connection="DSN=nasis_local;UID=NasisSqlRO;PWD=nasisRe@d0n1y")
   
@@ -169,6 +157,9 @@ get_component_esd_data_from_NASIS_db <- function() {
   # close connection
   RODBC::odbcClose(channel)
   
+  # recode metadata domains
+  d <- .metadata_replace(d)
+  
   # done
   return(d)
 }
@@ -182,8 +173,10 @@ get_copedon_from_NASIS_db <- function() {
     stop('please install the `RODBC` package', call.=FALSE)
   
   q <- "SELECT coiidref as coiid, peiidref as peiid, upedonid as pedon_id, rvindicator as representative 
-  FROM copedon_View_1
-  LEFT OUTER JOIN pedon_View_1 ON copedon_View_1.peiidref = pedon_View_1.peiid;
+  
+  FROM copedon_View_1 copedon
+  
+  LEFT OUTER JOIN pedon ON pedon.peiid = copedon.peiidref;
   "
   # setup connection local NASIS
   channel <- RODBC::odbcDriverConnect(connection="DSN=nasis_local;UID=NasisSqlRO;PWD=nasisRe@d0n1y")
@@ -205,8 +198,12 @@ get_component_horizon_data_from_NASIS_db <- function() {
   if(!requireNamespace('RODBC'))
     stop('please install the `RODBC` package', call.=FALSE)
   
-  q <- "SELECT coiidref as coiid, chiid, hzname, hzdept_r, hzdepb_r, fragvoltot_r, sandtotal_r, silttotal_r, claytotal_r, om_r, dbovendry_r, ksat_r, awc_r, lep_r, sar_r, ec_r, cec7_r, sumbases_r, ph1to1h2o_r
-  FROM chorizon_View_1 
+  q <- "SELECT coiidref as coiid, chiid, hzname, hzdept_r, hzdepb_r, fragvoltot_l, fragvoltot_r, fragvoltot_h, sandtotal_r, silttotal_r, claytotal_r, texture, om_r, dbovendry_r, ksat_r, awc_r, lep_r, sar_r, ec_r, cec7_r, sumbases_r, ph1to1h2o_r
+  
+  FROM chorizon_View_1 ch
+  
+  LEFT OUTER JOIN (SELECT * FROM chtexturegrp WHERE rvindicator = 'TRUE') AS cht ON cht.chiidref = ch.chiid
+
   ORDER BY coiidref, hzdept_r ASC;"
   
   # setup connection local NASIS
